@@ -4,6 +4,7 @@ from django.utils.translation import gettext_lazy as _
 from django.template.loader import get_template
 from django.utils.functional import cached_property
 from django.template.loaders.app_directories import Loader
+from django.template.exceptions import TemplateDoesNotExist
 
 from snowebsvg import settings
 
@@ -157,15 +158,26 @@ class Svg(models.Model):
     def render_django(self, theme=settings.SVG_DEFAULT_THEME, size=settings.SVG_DEFAULT_SIZE):
         """
         Method for rendering Django template code
+
+        :param theme: Theme, defaults to :ref:`SVG_DEFAULT_THEME <references_settings>`
+        :param size: Size, defaults :ref:`SVG_DEFAULT_SIZE <references_settings>`
         """
-        svg_template = get_template("snowebsvg/collections/%s/django.html" % self.group.collection.key)
-        return svg_template.render({
+        context = {
             'self': self,
             'theme': theme,
             'size': size,
             'start': '{%',
             'end': '%}'
-        })
+        }
+        try:
+            svg_template = get_template("snowebsvg/collections/%s/%s/_django.html" % (
+                self.group.collection.key,
+                self.group.key,
+            ))
+            return svg_template.render(context)
+        except TemplateDoesNotExist:
+            svg_template = get_template("snowebsvg/common/django.html")
+            return svg_template.render(context)
 
     def render_html(self, theme=settings.SVG_DEFAULT_THEME, size=settings.SVG_DEFAULT_SIZE):
         """
@@ -174,13 +186,37 @@ class Svg(models.Model):
         :param theme: Theme, defaults to :ref:`SVG_DEFAULT_THEME <references_settings>`
         :param size: Size, defaults :ref:`SVG_DEFAULT_SIZE <references_settings>`
         """
-        svg_template = get_template("snowebsvg/collections/%s/%s/%s" % (
+        svg_template = get_template("snowebsvg/collections/%s/%s/%s.html" % (
             self.group.collection.key,
             self.group.key,
-            self.key + '.html'
+            self.key
         ))
         return svg_template.render({
             'self': self,
             'theme': theme,
             'size': size
         })
+
+    def render_preview(self, theme=settings.SVG_DEFAULT_THEME, size=settings.SVG_DEFAULT_SIZE):
+        """
+        Method for rendering a preview of Svg to HTML
+        If _preview.html exist, then render the preview html file
+        If _preview does not exist, then fall back on render_html()
+
+        :param theme: Theme, defaults to :ref:`SVG_DEFAULT_THEME <references_settings>`
+        :param size: Size, defaults :ref:`SVG_DEFAULT_SIZE <references_settings>`
+        """
+        context = {
+            'self': self,
+            'theme': theme,
+            'size': size
+        }
+        try:
+            svg_template = get_template("snowebsvg/collections/%s/%s/_preview.html" % (
+                self.group.collection.key,
+                self.group.key,
+            ))
+            return svg_template.render(context)
+        except TemplateDoesNotExist:
+            svg_template = get_template("snowebsvg/common/preview.html")
+            return svg_template.render(context)
